package org.jboss.soa.modeshape.factory;

import java.io.File;
import java.util.HashMap;
import java.util.Map;
import java.util.ServiceLoader;

import javax.jcr.Repository;
import javax.jcr.RepositoryException;
import javax.jcr.RepositoryFactory;

import org.apache.log4j.Logger;

import org.modeshape.common.collection.Problem;
import org.modeshape.jcr.JcrConfiguration;
import org.modeshape.jcr.JcrEngine;

/**
 * 
 * @author mbaluch
 */
public class RepositoryReferenceFactory {

	static final Logger log = Logger.getLogger(RepositoryReferenceFactory.class);
	
	private static JcrEngine engine = null;

	public static Repository getRepository(String repositoryName) {
		String useJndiProp = System.getProperty("modeshape.usejndi", "true");
		if("true".equals(useJndiProp.toLowerCase())) {
			return getServerRepository(repositoryName);
		} else {
			return getStandaloneRepository(repositoryName);
		}
//		return ("true".equals(useJndiProp.toLowerCase())) ? getServerRepository(repositoryName)
//				: getStandaloneRepository(repositoryName);
	}

	public static synchronized Repository getStandaloneRepository(String repositoryName) {
		System.out.println("Retrieving standalone repository: " + repositoryName);
		String config = System.getProperty("modeshape.config");
		if (config != null) {
			if(new File(config).exists()) {
				try {
					if (engine == null) {
						JcrConfiguration configuration = new JcrConfiguration();
						configuration.loadFrom(config);
						if (!configuration.getProblems().isEmpty()) {
							for (Problem problem : configuration.getProblems()) {
								log.error(problem);
							}
							throw new RuntimeException(configuration.getProblems()
									.toString());
						}
						engine = configuration.build();
						engine.start();
					}
					return engine.getRepository(repositoryName);
				} catch (RepositoryException e) {
					log.debug(e);
					throw new RuntimeException(e.getMessage(), e.getCause());
				} catch (Exception e) {
					log.debug(e);
					throw new RuntimeException(e.getMessage(), e.getCause());
				}
			}
			throw new RuntimeException("Path does not exist: " + config);
		}
		throw new RuntimeException("Property not set: modeshape.config");
	}

	public static Repository getServerRepository(String repositoryName) {
		System.out.println("Retrieving server repository: " + repositoryName);
		try {
			Map<String, String> parameters = new HashMap<String, String>();
			parameters.put("org.modeshape.jcr.URL", "jndi:jcr/local?repositoryName=" + repositoryName);
			Repository repository = null;
			for (RepositoryFactory aFactory : ServiceLoader.load(RepositoryFactory.class)) {
				repository = aFactory.getRepository(parameters);
				if (repository != null) {
					return repository;
				}
			}
		} catch (Exception e) {
			log.debug(e);
			throw new RuntimeException(e.getMessage(), e.getCause());
		}
		throw new RuntimeException("Repository not found: " + repositoryName);
	}

}
