package org.jboss.soa.modeshape.qa.tests;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.Statement;
import java.sql.Types;

import javax.jcr.Node;
import javax.jcr.NodeIterator;
import javax.jcr.Repository;
import javax.jcr.Session;
import javax.jcr.ValueFactory;
import javax.jcr.query.Query;
import javax.jcr.query.QueryManager;
import javax.jcr.query.QueryResult;
import javax.jcr.query.qom.Column;
import javax.jcr.query.qom.Constraint;
import javax.jcr.query.qom.Ordering;
import javax.jcr.query.qom.QueryObjectModelFactory;
import javax.jcr.query.qom.QueryObjectModelConstants;
import javax.jcr.query.qom.Selector;
import javax.naming.InitialContext;
import javax.sql.DataSource;

import org.testng.Assert;

import org.jboss.soa.modeshape.factory.RepositoryReferenceFactory;

import org.modeshape.jcr.JcrRepository;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

@Test
public class BrokenQueryTest {

	@SuppressWarnings("deprecation")
	@DataProvider(name = "query-languages")
	Object[][] getQueries() {
		return new Object[][] {
//				{ Query.SQL, "SELECT * FROM 'nt:unstructured' WHERE query_property = 'testvalue'" },
//				{ Query.XPATH, "/jcr:root/queryNode" },
//				{ Query.JCR_SQL2, "SELECT * FROM [nt:base] WHERE PATH([nt:base]) = '/queryNode'" },
//				{ Query.JCR_JQOM, "nt:unstructured" },
				{ }
		};
	};

	@BeforeClass
	public void initRepository() throws Exception {
		Repository repository = RepositoryReferenceFactory
				.getRepository("eds");
		Session session = repository.login();
		while (session.nodeExists("/queryNode")) {
			session.removeItem("/queryNode");
		}
		Node n = session.getRootNode().addNode("queryNode", "nt:unstructured");
		n.setProperty("query_property", "testvalue");
		session.save();
		session.logout();
	}

	@Test(enabled = true)
	public void testFulltextSearch()
			throws Exception {
		Repository repository = RepositoryReferenceFactory
				.getRepository("eds");
		Session session = repository.login();
		QueryManager queryManager = session.getWorkspace().getQueryManager();
		ValueFactory vf = session.getValueFactory();

		Query query;

		query = queryManager.createQuery("testvalue", JcrRepository.QueryLanguage.SEARCH);
		QueryResult result = query.execute();

		NodeIterator nodeIter = result.getNodes();

		Assert.assertTrue(nodeIter.hasNext(), "Node exists");
		Node node = nodeIter.nextNode();
		System.out.println(node);
		Assert.assertEquals(node.getName(), "queryNode");
		Assert.assertFalse(nodeIter.hasNext(), "Only one node exists");
		session.logout();
/*
		session = repository.login();
		Node n = session.getRootNode().addNode("testFolder", "nt:folder");
		System.out.println("This is not printed");
		session.logout();
*/
	}
}
